@@ -12,13 +12,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from six.moves import queue, range
+
 import atexit
 import logging
 import threading
 
-from six.moves import queue
-from six.moves import range
-
 from opencensus.common.transports import base
 from opencensus.trace import execution_context
 
